about summary refs log tree commit diff stats
path: root/src/LYrcFile.c
diff options
context:
space:
mode:
authorThomas E. Dickey <dickey@invisible-island.net>1999-12-15 11:25:06 -0500
committerThomas E. Dickey <dickey@invisible-island.net>1999-12-15 11:25:06 -0500
commitf61041c10496785b2833ee4f76ef3edc9792b1bd (patch)
treee9c127318bebeb1a4944bf636fca5bd188a90771 /src/LYrcFile.c
parent4525eb4b32fdf2124e246285af59a1e14ecbf551 (diff)
downloadlynx-snapshots-f61041c10496785b2833ee4f76ef3edc9792b1bd.tar.gz
snapshot of project "lynx", label v2-8-3dev_17
Diffstat (limited to 'src/LYrcFile.c')
-rw-r--r--src/LYrcFile.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/LYrcFile.c b/src/LYrcFile.c
index a2e65c26..d03f49d0 100644
--- a/src/LYrcFile.c
+++ b/src/LYrcFile.c
@@ -452,7 +452,7 @@ PUBLIC void read_rc ARGS1(FILE *, fp)
 
 #ifdef EXP_PERSISTENT_COOKIES
 	/*
 	 *  File in which to store persistent cookies.
 	 */
 	} else if (FIND_KEYWORD(cp, "cookie_file")) {
 	    cp = SkipEquals(cp);
@@ -995,10 +995,10 @@ querying the user for an invalid path or domain.\n\
 
 #ifdef EXP_PERSISTENT_COOKIES
     /*
-     *  Cookie file.
+     *  Cookie read file.
      */
     write_list(fp, gettext("\
-cookie_file specifies the file in which to store persistent cookies.\n\
+cookie_file specifies the file from which to read persistent cookies.\n\
 The default is ~/.lynx_cookies.\n\
 "));
     fprintf(fp, "cookie_file=%s\n\n",
@@ -452,7 +452,7 @@ PUBLIC void read_rc ARGS1(FILE *, fp)
 #ifdef EXP_PERSISTENT_COOKIES
 	/*
-	 *  File in which to store persistent cookies.
+	 *  File from which to read persistent cookies.
 	 */
 	} else if (FIND_KEYWORD(cp, "cookie_file")) {